"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeSymbols = exports.decodeSvgPath = exports.remarkDeepSVGPaths = exports.checkIsSVGMultiColor = exports.numToDecimal2 = void 0;
const equal_1 = require("bear-jsutils/equal");
const string_1 = require("bear-jsutils/string");
const cheerio = __importStar(require("cheerio"));
/**
 * 保留小數第二位
 * @returns {string}
 * @param num
 */
const numToDecimal2 = (num) => {
    const f = Math.floor(num * 100) / 100;
    let s = f.toString();
    let rs = s.indexOf('.');
    if (rs < 0) {
        rs = s.length;
        s += '.';
    }
    while (s.length <= rs + 2) {
        s += '0';
    }
    return Number(s);
};
exports.numToDecimal2 = numToDecimal2;
const onlyUnique = (value, index, self) => {
    return self.indexOf(value) === index;
};
const getMultiColor = (svgNode) => {
    return svgNode.reduce((curr, row) => {
        var _a, _b, _c;
        if (typeof row !== 'string' && row.type === 'element') {
            if (row.tagName === 'path') {
                const colors = [];
                if ((_a = row.properties) === null || _a === void 0 ? void 0 : _a.fill) {
                    colors.push(row.properties.fill.toLocaleString());
                }
                if ((_b = row.properties) === null || _b === void 0 ? void 0 : _b['fill-opacity']) {
                    colors.push((_c = row.properties) === null || _c === void 0 ? void 0 : _c['fill-opacity'].toString().replace('0.', '.'));
                }
                curr.push(colors.join('_'));
                return curr;
            }
            else if (row.children && row.children.length > 0) {
                return getMultiColor(row.children);
            }
        }
        return curr;
    }, []);
};
/**
 * get svg paths
 * @param svgNode
 */
const checkIsSVGMultiColor = (svgNode) => {
    const fillColors = getMultiColor(svgNode);
    const colorLength = fillColors.filter(onlyUnique).length;
    return colorLength > 1;
};
exports.checkIsSVGMultiColor = checkIsSVGMultiColor;
/**
 * get svg paths
 * @param svgNode
 * @param isMultiColor
 */
const remarkDeepSVGPaths = (svgNode, isMultiColor = true) => {
    return svgNode.reduce((curr, row) => {
        var _a, _b, _c, _d;
        if (typeof row !== 'string' && row.type === 'element') {
            if (row.tagName === 'path') {
                const properties = [];
                if (isMultiColor) {
                    if ((_a = row.properties) === null || _a === void 0 ? void 0 : _a['fill-opacity']) {
                        properties.push(`fill-opacity="${(_b = row.properties) === null || _b === void 0 ? void 0 : _b['fill-opacity'].toString().replace('0.', '.')}"`);
                    }
                    if ((_c = row.properties) === null || _c === void 0 ? void 0 : _c.fill) {
                        properties.push(`fill="${row.properties.fill.toLocaleString()}"`);
                    }
                }
                if ((_d = row.properties) === null || _d === void 0 ? void 0 : _d.d) {
                    const d = row.properties.d
                        .toString()
                        .replace(/\n/g, '')
                        .replace(/\t/g, '');
                    properties.push(`d="${d}"`);
                }
                curr.push(`<path ${properties.join(' ')}/>`);
                return curr;
            }
            else if (row.children && row.children.length > 0) {
                return (0, exports.remarkDeepSVGPaths)(row.children, isMultiColor);
            }
        }
        return curr;
    }, []);
};
exports.remarkDeepSVGPaths = remarkDeepSVGPaths;
/**
 * 解析SVGPath
 * @param svgContent
 */
const decodeSvgPath = (svgContent) => {
    const $ = cheerio.load(svgContent);
    const root = $('svg');
    const viewBox = root.attr('viewBox');
    const fillDiffColor = [];
    const paths = [];
    root.find('path').each((index, element) => {
        var _a, _b, _c, _d, _e;
        const d = (_a = $(element).attr('d')) === null || _a === void 0 ? void 0 : _a.toString().replace(/\n/g, '').replace(/\t/g, '');
        const fill = (_b = $(element).attr('fill')) === null || _b === void 0 ? void 0 : _b.toLocaleString();
        const fillOpacity = (_c = $(element).attr('fill-opacity')) === null || _c === void 0 ? void 0 : _c.toString().replace('0.', '.');
        const fillRule = (_d = $(element).attr('fill-rule')) === null || _d === void 0 ? void 0 : _d.toString();
        const clipRule = (_e = $(element).attr('clip-rule')) === null || _e === void 0 ? void 0 : _e.toString();
        if (fill && !fillDiffColor.includes(fill)) {
            fillDiffColor.push(fill);
        }
        paths.push({
            d,
            fill,
            fillOpacity,
            clipRule,
            fillRule,
        });
    });
    const isMultiColor = fillDiffColor.length >= 2;
    return {
        viewBox,
        paths: paths.map(row => {
            const properties = [];
            if (isMultiColor) {
                if (row.fill) {
                    properties.push(`fill="${row.fill}"`);
                }
                if (row.fillOpacity) {
                    properties.push(`fill-opacity="${row.fillOpacity}"`);
                }
            }
            if (row.fillRule) {
                properties.push(`fill-rule="${row.fillRule}"`);
            }
            if (row.clipRule) {
                properties.push(`clip-rule="${row.clipRule}"`);
            }
            if (row.d) {
                const d = row.d;
                properties.push(`d="${d}"`);
            }
            return `<path ${properties.join(' ')}/>`;
        }),
    };
};
exports.decodeSvgPath = decodeSvgPath;
/**
 * 解析Symbols
 * @param symbolsContent
 */
const decodeSymbols = (symbolsContent) => {
    const symbols = symbolsContent.match(equal_1.regPattern.symbol);
    const idPrefix = 'icon_';
    const data = [];
    if (symbols !== null) {
        symbols.forEach(symbol => {
            const idRes = new RegExp(equal_1.regPattern.htmlAttrId).exec(symbol);
            if (idRes && idRes.length > 1) {
                // const targetSvgFile = path.join(sourceDirPath, `${idRes[1].replace(idPrefix,'')}.svg`);
                const pathContent = (0, string_1.removeStartEnd)(symbol, '<symbol\\b[^>]*?(?:viewBox=\\"(\\b[^"]*)\\")?>', '<\\/symbol>');
                const viewBox = new RegExp(/<symbol\b[^>]*?(?:viewBox=\"(\b[^"]*)\")?>/).exec(symbol);
                // ======== write type file start ========
                data.push({
                    code: idRes[1].replace(idPrefix, ''),
                    viewBox: viewBox ? viewBox[1] : '0 0 1024',
                    content: pathContent.trim().replace('    ', ''),
                });
                // ======== write type file end ========
            }
        });
    }
    return data;
};
exports.decodeSymbols = decodeSymbols;
//# sourceMappingURL=utils.js.map